@@ -14,13 +14,11 @@ impl ContentDisposition {
 
         let field_name = content_disposition
             .and_then(|val| ContentDispositionAttr::Name.extract_from(val))
-            .and_then(|attr| std::str::from_utf8(attr).ok())
-            .map(String::from);
+            .map(|attr| attr.into_owned());
 
         let file_name = content_disposition
             .and_then(|val| ContentDispositionAttr::FileName.extract_from(val))
-            .and_then(|attr| std::str::from_utf8(attr).ok())
-            .map(String::from);
+            .map(|attr| attr.into_owned());
 
         ContentDisposition { field_name, file_name }
     }
